
Copyright Detail for Python for Everybody
==========================================

This work is licensed under a Creative Common
Attribution-NonCommercial-ShareAlike 3.0 Unported License. This license
is available at

`creativecommons.org/licenses/by-nc-sa/3.0/ <creativecommons.org/licenses/by-nc-sa/3.0/>`_.

I would have preferred to license the book under the less restrictive
CC-BY-SA license. But unfortunately there are a few unscrupulous
organizations who search for and find freely licensed books, and then
publish and sell virtually unchanged copies of the books on a print on
demand service such as LuLu or CreateSpace. CreateSpace has (thankfully)
added a policy that gives the wishes of the actual copyright holder
preference over a non-copyright holder attempting to publish a freely
licensed work. Unfortunately there are many print-on-demand services and
very few have as well-considered a policy as CreateSpace.

Regretfully, I added the NC element to the license this book to give me
recourse in case someone tries to clone this book and sell it
commercially. Unfortunately, adding NC limits uses of this material that
I would like to permit. So I have added this section of the document to
describe specific situations where I am giving my permission in advance
to use the material in this book in situations that some might consider
commercial.


*
  If you are printing a limited number of copies of all or part of
  this book for use in a course (e.g., like a coursepack), then you
  are granted CC-BY license to these materials for that purpose.

*
  If you are a teacher at a university and you translate this book
  into a language other than English and teach using the translated
  book, then you can contact me and I will granted you a CC-BY-SA
  license to these materials with respect to the publication of your
  translation. In particular, you will be permitted to sell the
  resulting translated book commercially.

If you are intending to translate the book, you may want to contact me
so we can make sure that you have all of the related course materials so
you can translate them as well.

Of course, you are welcome to contact me and ask for permission if these
clauses are not sufficient. In all cases, permission to reuse and remix
this material will be granted as long as there is clear added value or
benefit to students or teachers that will accrue as a result of the new
work.

| Charles Severance
| www.dr-chuck.com
| Ann Arbor, MI, USA
| September 9, 2013
